Learn R Programming

ggDoubleHeat (version 0.1.2)

pitts_emojis: Popular Emojis

Description

The most popular Emoji of a given week in a given category from the Meltwater Tweet sample. They can be rendered by using "richtext" with annotate().

Usage

pitts_emojis

Arguments

Format

An object of class character of length 270.