powered by
The most popular Emoji of a given week in a given category from the Meltwater Tweet sample. They can be rendered by using "richtext" with annotate().
"richtext"
annotate()
pitts_emojis
An object of class character of length 270.
character